JSDoc: Class: ColorEditor

# Class: ColorEditor

## SlickGridColors.ColorEditor

ColorEditor

This class represents a color editor defined by the SlickGrid project.

Note, this object is heavily based on classes in slick.editors.js and in the documentation that can be found here.

Also see ColorFormatter, a function in charge of formatting colors for the SlickGrid object.

## Constructor

#### new ColorEditor(args)

##### Parameters:

Name | Type | Description
--- | --- | ---
`args` | object | Arguments passed by SlickGrid.

Source:
  - color-editor.js, line 35